IntrinsicResult class

Result represents the result of an intrinsic call.

Constructors

IntrinsicResult(Value? result, {bool done = true})
Result constructor taking a Value, and an optional done flag.
IntrinsicResult.fromNum(double resultNum, {bool done = true})
Result constructor for a simple numeric result.
IntrinsicResult.fromString(String resultStr, {bool done = true})
Result constructor for a simple string result.
IntrinsicResult.fromTruth(bool resultBool, {bool done = true})
Result constructor for a simple boolean result.

Properties

done bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
result Value?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

emptyString IntrinsicResult
Static Result representing "" (empty string).
getter/setter pair
false_ IntrinsicResult
Static Result representing false (0.0).
getter/setter pair
null_ IntrinsicResult
Static Result representing null (no value).
getter/setter pair
true_ IntrinsicResult
Static Result representing true (1.0).
getter/setter pair
waiting IntrinsicResult
Static Result representing a need to wait, with no in-progress value.
getter/setter pair